Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(826)

Unified Diff: third_party/WebKit/Source/core/layout/LayoutObject.h

Issue 1970183002: Don't use canCollapseAnonymousBlockChild() to determine whether to truncate text. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Declaration soup - aka LayoutTest. Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/LayoutObject.h
diff --git a/third_party/WebKit/Source/core/layout/LayoutObject.h b/third_party/WebKit/Source/core/layout/LayoutObject.h
index 484b99accf55737dadfab10d60bcd684daec4194..7e43a2bfeefe452ca909fef3a04b7a88f9e0e125 100644
--- a/third_party/WebKit/Source/core/layout/LayoutObject.h
+++ b/third_party/WebKit/Source/core/layout/LayoutObject.h
@@ -780,13 +780,14 @@ public:
virtual LayoutMultiColumnSpannerPlaceholder* spannerPlaceholder() const { return nullptr; }
bool isColumnSpanAll() const { return style()->getColumnSpan() == ColumnSpanAll && spannerPlaceholder(); }
// We include isLayoutButton in this check because buttons are implemented
// using flex box but should still support first-line|first-letter.
// The flex box and grid specs require that flex box and grid do not
// support first-line|first-letter, though.
// TODO(cbiesinger): Remove when buttons are implemented with align-items instead
// of flex box. crbug.com/226252.
- bool canHaveFirstLineOrFirstLetterStyle() const { return isLayoutBlockFlow() || isLayoutButton(); }
+ bool behavesLikeBlockContainer() const { return isLayoutBlockFlow() || isLayoutButton(); }
bool hasFilterOrReflection() const;
« no previous file with comments | « third_party/WebKit/Source/core/layout/LayoutBlockFlowLine.cpp ('k') | third_party/WebKit/Source/core/layout/LayoutObject.cpp » ('j') | no next file with comments »
@@ -780,13 +780,14 @@ public:
virtual LayoutMultiColumnSpannerPlaceholder* spannerPlaceholder() const { return nullptr; }
bool isColumnSpanAll() const { return style()->getColumnSpan() == ColumnSpanAll && spannerPlaceholder(); }
- // We include isLayoutButton in this check because buttons are implemented
- // using flex box but should still support first-line|first-letter.
+ // We include isLayoutButton() in this check, because buttons are
+ // implemented using flex box but should still support things like
+ // first-line, first-letter and text-overflow.
// The flex box and grid specs require that flex box and grid do not
// support first-line|first-letter, though.

Powered by Google App Engine
This is Rietveld 408576698